@@ -35,6 +35,7 @@ from skrobot.utils.listify import listify
 from skrobot.utils import urdf
 from skrobot.utils.urdf import URDF
 
+
 logger = getLogger(__name__)
 
 
@@ -1484,6 +1485,7 @@ class CascadedLink(CascadedCoords):
 
         col = col_offset
         i = 0
+        world_default_coords = Coordinates()
         while col < (col_offset + jdim):
             ul = union_link_list[i]
             row = 0
@@ -1509,8 +1511,9 @@ class CascadedLink(CascadedCoords):
                         child_link = joint.child_link
                         parent_link = joint.parent_link
                         default_coords = joint.default_coords
-                        world_default_coords = parent_link.copy_worldcoords().\
-                            transform(default_coords)
+                        # set new coordinates to world_default_coords.
+                        parent_link.worldcoords().\
+                            transform(default_coords, out=world_default_coords)
 
                         jacobian = joint.calc_jacobian(
                             jacobian,
@@ -1692,6 +1695,7 @@ class RobotModel(CascadedLink):
                     mesh.visual.face_colors = visual.material.color
 
             mesh.apply_transform(visual.origin)
+            mesh.metadata["origin"] = visual.origin
             meshes.append(mesh)
         return meshes
 
